var format = require('util').format;
var $ = require('cheerio');

/**
 * Returns output for desired custom element
 * @param {object} element - Element as a Cheerio object.
 * @returns {string} HTML converted from a custom element to table syntax.
 */
module.exports = function(element) {
  var component = $(element);
  var inner     = $(element).html();

  switch (element.name) {
    // <column>
    case this.components.columns:
      return this.makeColumn(component, 'columns');

    // <row>
    case this.components.row:
      var classes = ['row'];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }

      return format('<table class="%s"><tbody><tr>%s</tr></tbody></table>', classes.join(' '), inner);

    // <button>
    case this.components.button:
      // If we have the href attribute we can create an anchor for the inner of the button;
      if (component.attr('href')) {
        inner = format('<a href="%s">%s</a>', component.attr('href'), inner);
      }

      // If the button is expanded, it needs a <center> tag around the content
      if (component.hasClass('expand')) {
        inner = format('<center>%s</center>', inner);
      }

      // The .button class is always there, along with any others on the <button> element
      var classes = ['button'];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }

      return format('<table class="%s"><tr><td><table><tr><td>%s</td></tr></table></td></tr></table>', classes.join(' '), inner);

    // <container>
    case this.components.container:
      var classes = ['container'];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }

      return format('<table class="%s"><tbody><tr><td>%s</td></tr></tbody></table>', classes.join(' '), inner);

    // <inky>
    case this.components.inky:
      return '<tr><td><img src="https://raw.githubusercontent.com/arvida/emoji-cheat-sheet.com/master/public/graphics/emojis/octopus.png" /></tr></td>';

    // <block-grid>
    case this.components.blockGrid:
      var classes = ['block-grid', 'up-'+component.attr('up')];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }
      return format('<table class="%s"><tr>%s</tr></table>', classes.join(' '), inner);

    // <menu>
    case this.components.menu:
      var classes = ['menu'];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }

      return format('<table class="%s"><tr>%s</tr></table>', classes.join(' '), inner);

    // <item>
    case this.components.menuItem:
      return format('<td><a href="%s">%s</a></td>', component.attr('href'), inner);

    // <center>
    case this.components.center:
      if (component.children().length > 0) {
        component.children().attr({
          align:'center', class:'center'
        });
      }

      return format('%s', $.html(element));

    // <callout>
    case this.components.callout:
      var classes = ['callout'];
      if (component.attr('class')) {
        classes = classes.concat(component.attr('class').split(' '));
      }

      return format('<table><tr><th class="%s">%s</th></tr></table>', classes.join(' '), inner);

    default:
      // If it's not a custom component, return it as-is
      return format('<tr><td>%s</td></tr>', $.html(element));
  }
}
